#  tests for gdal-2.2.2-py27h58389d3_1 (this is a generated file);
print('===== testing package: gdal-2.2.2-py27h58389d3_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from osgeo import gdal
from osgeo import ogr
from osgeo import osr

# Avoid the regressing from https://github.com/conda-forge/gdal-feedstock/pull/129
# See https://github.com/conda-forge/gdal-feedstock/issues/131
from osgeo.gdal_array import *

driver = gdal.GetDriverByName("netCDF")
assert driver is not None, "netcdf not linked in correctly"

driver = gdal.GetDriverByName("HDF4")
assert driver is not None, "hdf4 not linked in correctly"

driver = gdal.GetDriverByName("HDF5")
assert driver is not None, "hdf5 not linked in correctly"

driver = gdal.GetDriverByName("GTiff")
assert driver is not None, "tiff not linked in correctly"

driver = gdal.GetDriverByName("PNG")
assert driver is not None, "png not linked in correctly"

driver = gdal.GetDriverByName("JPEG")
assert driver is not None, "jpeg not linked in correctly"

driver = gdal.GetDriverByName("GPKG")
assert driver is not None

# only available when libkea successfully linked in.
driver = gdal.GetDriverByName("KEA")
assert driver is not None, "kealib not linked in correctly"

# only available when xerces-c++ successfully linked in.
driver = ogr.GetDriverByName("GML")
assert driver is not None, "xerces-c not linked in correctly"

# only available when openjpeg successfully linked in.
driver = gdal.GetDriverByName("JP2OpenJPEG")
assert driver is not None, "openjpeg not linked in correctly"

# only available when curl successfully linked in.
driver = gdal.GetDriverByName("WCS")
assert driver is not None, "curl not linked in correctly"

# only available when freexl successfully linked in.
driver = ogr.GetDriverByName("XLS")
assert driver is not None, "freexl not linked in correctly"

# only available when expat successfully linked in.
driver = ogr.GetDriverByName("KML")
assert driver is not None, "kml not linked in correctly"

# only available when SQLite successfully linked in.
driver = ogr.GetDriverByName("SQLite")
assert driver is not None, "sqlite not linked in correctly"

# only available when PostgreSQL successfully linked in.
driver = ogr.GetDriverByName("PostgreSQL")
assert driver is not None, "postgres not linked in correctly"

def has_geos():
    pnt1 = ogr.CreateGeometryFromWkt( 'POINT(10 20)' )
    pnt2 = ogr.CreateGeometryFromWkt( 'POINT(30 20)' )
    ogrex = ogr.GetUseExceptions()
    ogr.DontUseExceptions()
    hasgeos = pnt1.Union( pnt2 ) is not None
    if ogrex:
        ogr.UseExceptions()
    return hasgeos

assert has_geos(), 'GEOS not available within GDAL'

def has_proj():
    sr1 = osr.SpatialReference()
    sr1.ImportFromEPSG(4326) # lat, lon.
    sr2 = osr.SpatialReference()
    sr2.ImportFromEPSG(28355) # GDA94/MGA zone 55.
    osrex = osr.GetUseExceptions()
    osr.UseExceptions()
    hasproj = True
    # Use exceptions to determine if we have proj and epsg files
    # otherwise we can't reliably determine if it has failed.
    try:
        trans = osr.CoordinateTransformation(sr1, sr2)
    except RuntimeError:
        hasproj = False
    return hasproj

assert has_proj(), 'PROJ not available within GDAL'

# Test https://github.com/swig/swig/issues/567
def make_geom():
    geom = ogr.Geometry(ogr.wkbPoint)
    geom.AddPoint_2D(0, 0)
    return geom

def gen_list(N):
    for i in range(N):
        geom = make_geom()
        yield i

N = 10
assert list(gen_list(N)) == list(range(N))

# This module does some additional tests.
import extra_tests
#  --- run_test.py (end) ---

print('===== gdal-2.2.2-py27h58389d3_1 OK =====');
print("import: 'osr'")
import osr

print("import: 'gdal'")
import gdal

print("import: 'gdalconst'")
import gdalconst

print("import: 'osgeo'")
import osgeo

print("import: 'osgeo.ogr'")
import osgeo.ogr

print("import: 'osgeo.gdal'")
import osgeo.gdal

print("import: 'osgeo._gdal'")
import osgeo._gdal

print("import: 'osgeo._gdalconst'")
import osgeo._gdalconst

print("import: 'osgeo._ogr'")
import osgeo._ogr

print("import: 'osgeo._osr'")
import osgeo._osr

